# genereg

[![Documentation Status](https://readthedocs.org/projects/genereg/badge/?version=latest)](https://genereg.readthedocs.io/en/latest/?badge=latest)

This library implements a method for analyzing the regulation systems of target genes in a specific genetic pathology, such as a cancer. Adopting a linear regression approach, it builds a predictive model for the regulation of target genes expression, in order to identify the relevant features that explain the regulation of each gene of interest within patients affected by the pathology under analysis.
The regulation system of each target gene is analyzed singularly and independently, by assessing the effect of multiple regulatory factors on its expression, such as its methylation, the expression of other genes or the effect of transcription factors.

The full documentation can be found at the following link: https://genereg.readthedocs.io
